# redrcp

[![PyPI - Version](https://img.shields.io/pypi/v/redrcp?pypiBaseUrl=https://test.pypi.org
)](https://test.pypi.org/simple/redrcp)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/redrcp?pypiBaseUrl=https://test.pypi.org)](https://test.pypi.org/simple/redrcp)

-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install redrcp
```

## License

`redrcp` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
